@@ -110,7 +110,8 @@ class FormHandler(object):
             schema = self.hooks['get_schema'](self, unsafe_params, state)
         else:
             assert self.schema
-            return self.schema
+            schema = self.schema
+        return schema
 
     def _make_state(self, defaults, state_attrs):
         """ Makes a state object and returns it. """
